@@ -1,5 +1,5 @@
 pub mod contract;
-mod error;
+pub mod error;
 pub mod msg;
 pub mod state;
 pub mod query;
